@@ -22,6 +22,7 @@ class NISARProduct(ASFStackableProduct):
         'rangeBandwidth': {'path': ['AdditionalAttributes', ('Name', 'RANGE_BANDWIDTH_CONCAT'), 'Values']},
         'productionConfiguration': {'path': ['AdditionalAttributes', ('Name', 'PRODUCTION_PIPELINE'), 'Values', 0]},
         'processingLevel': {'path': ['AdditionalAttributes', ('Name', 'PRODUCT_TYPE'), 'Values', 0]},
+        'bytes': {'path': ['DataGranule', 'ArchiveAndDistributionInformation']},
     }
     def __init__(self, args: Dict = {}, session: ASFSession = ASFSession()):
         super().__init__(args, session)
@@ -34,6 +35,10 @@ class NISARProduct(ASFStackableProduct):
 
         if self.properties.get('groupID') is None:
             self.properties['groupID'] = self.properties['sceneName']
+        self.properties['bytes'] = {
+            entry['Name']: {'bytes': entry['SizeInBytes'], 'format': entry['Format']}
+            for entry in self.properties['bytes']
+        }
 
     @staticmethod
     def get_default_baseline_product_type() -> Union[str, None]:
